==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/customers.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	customers.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ENTRY_MEMO' => 'Memo:',
	'ENTRY_NEW_PASSWORD' => 'Neues Passwort:',
	'ENTRY_PASSWORD_CUSTOMER' => 'Passwort:',
	'ENTRY_PAYMENT_UNALLOWED' => 'Nicht erlaubte Zahlungsmodule:',
	'ENTRY_SHIPPING_UNALLOWED' => 'Nicht erlaubte Versandmodule:',
	'HEADING_SUB_TITLE' => 'Kunden',
	'HEADING_TITLE' => 'Kunden',
	'HEADING_TITLE_SEARCH' => 'Suche:',
	'HEADING_TITLE_STATUS' => 'Kundengruppe',
	'NEW_ORDER' => 'Neue Bestellung ?',
	'PLEASE_SELECT' => 'Auswählen',
	'TABLE_HEADING_ACCOUNT_CREATED' => 'Erstellt am',
	'TABLE_HEADING_ACCOUNT_TYPE' => 'Konto',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_DATE_ADDED' => 'Datum',
	'TABLE_HEADING_FIRSTNAME' => 'Vorname',
	'TABLE_HEADING_GROUPIMAGE' => 'Icon',
	'TABLE_HEADING_LASTNAME' => 'Nachname',
	'TABLE_HEADING_NEW_VALUE' => 'Neuer Status',
	'TEXT_ACCOUNT' => 'Ja',
	'TEXT_ALL_CUSTOMERS' => 'Alle Gruppen',
	'TEXT_DATE' => 'Datum',
	'TEXT_DATE_ACCOUNT_CREATED' => 'Erstellt am:',
	'TEXT_DATE_ACCOUNT_LAST_MODIFIED' => 'letzte Änderung:',
	'TEXT_DELETE_INTRO' => 'Wollen Sie diesen Kunden wirklich löschen?',
	'TEXT_DELETE_REVIEWS' => '%s Bewertung(en) löschen',
	'TEXT_GUEST' => 'Nein',
	'TEXT_INFO_COUNTRY' => 'Land:',
	'TEXT_INFO_DATE_LAST_LOGON' => 'letzte Anmeldung:',
	'TEXT_INFO_HEADING_DELETE_CUSTOMER' => 'Kunden löschen',
	'TEXT_INFO_HEADING_STATUS_CUSTOMER' => 'Kundengruppe',
	'TEXT_INFO_NUMBER_OF_LOGONS' => 'Anzahl der Anmeldungen:',
	'TEXT_INFO_NUMBER_OF_REVIEWS' => 'Anzahl der Kundenrezensionen:',
	'TEXT_MARKED_ELEMENTS' => 'Markiertes Element',
	'TEXT_NO_CUSTOMER_HISTORY' => '--Keine Änderung bisher--',
	'TEXT_POSTER' => 'Verfasser',
	'TEXT_SELECT' => '--Auswahl--',
	'TEXT_TITLE' => 'Titel',
	'TYPE_BELOW' => 'Bitte unten eingeben'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/customers.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	customers.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ENTRY_MEMO' => 'Memo:',
	'ENTRY_NEW_PASSWORD' => 'Neues Passwort:',
	'ENTRY_PASSWORD_CUSTOMER' => 'Passwort:',
	'ENTRY_PAYMENT_UNALLOWED' => 'Nicht erlaubte Zahlungsmodule:',
	'ENTRY_SHIPPING_UNALLOWED' => 'Nicht erlaubte Versandmodule:',
	'HEADING_SUB_TITLE' => 'Kunden',
	'HEADING_TITLE' => 'Kunden',
	'HEADING_TITLE_SEARCH' => 'Suche:',
	'HEADING_TITLE_STATUS' => 'Kundengruppe',
	'NEW_ORDER' => 'Neue Bestellung ?',
	'PLEASE_SELECT' => 'Auswählen',
	'TABLE_HEADING_ACCOUNT_CREATED' => 'Erstellt am',
	'TABLE_HEADING_ACCOUNT_TYPE' => 'Konto',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_DATE_ADDED' => 'Datum',
	'TABLE_HEADING_FIRSTNAME' => 'Vorname',
	'TABLE_HEADING_GROUPIMAGE' => 'Icon',
	'TABLE_HEADING_LASTNAME' => 'Nachname',
	'TABLE_HEADING_NEW_VALUE' => 'Neuer Status',
	'TEXT_ACCOUNT' => 'Ja',
	'TEXT_ALL_CUSTOMERS' => 'Alle Gruppen',
	'TEXT_DATE' => 'Datum',
	'TEXT_DATE_ACCOUNT_CREATED' => 'Erstellt am:',
	'TEXT_DATE_ACCOUNT_LAST_MODIFIED' => 'letzte Änderung:',
	'TEXT_DELETE_INTRO' => 'Willst du diesen Kunden wirklich löschen?',
	'TEXT_DELETE_REVIEWS' => '%s Bewertung(en) löschen',
	'TEXT_GUEST' => 'Nein',
	'TEXT_INFO_COUNTRY' => 'Land:',
	'TEXT_INFO_DATE_LAST_LOGON' => 'Letzte Anmeldung:',
	'TEXT_INFO_HEADING_DELETE_CUSTOMER' => 'Kunden löschen',
	'TEXT_INFO_HEADING_STATUS_CUSTOMER' => 'Kundengruppe',
	'TEXT_INFO_NUMBER_OF_LOGONS' => 'Anzahl der Anmeldungen:',
	'TEXT_INFO_NUMBER_OF_REVIEWS' => 'Anzahl der Kundenrezensionen:',
	'TEXT_MARKED_ELEMENTS' => 'Markiertes Element',
	'TEXT_NO_CUSTOMER_HISTORY' => '--Keine Änderung bisher--',
	'TEXT_POSTER' => 'Verfasser',
	'TEXT_SELECT' => '--Auswahl--',
	'TEXT_TITLE' => 'Titel',
	'TYPE_BELOW' => 'Bitte unten eingeben',
    'TITLE_CUSTOMER' => 'Kunde'
);
